@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Search YouTube
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -24,7 +24,7 @@ has key => (
 
 has base => (
     is      => 'rw',
-    default => sub { 'https://www.googleapis.com/youtube/v3' },
+    default => sub { 'https://www.googleapis.com' },
 );
 
 
@@ -38,7 +38,7 @@ sub search {
     my ( $self, %args ) = @_;
 
     my $url = Mojo::URL->new( $self->base )
-        ->path('/search')
+        ->path('youtube/v3/search')
         ->query(
             %args,
             part => 'snippet',
@@ -89,7 +89,7 @@ WebService::YTSearch - Search YouTube
 
 =head1 VERSION
 
-version 0.0204
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ Your authorized access key.
 
 The base URL.
 
-Default: https://www.googleapis.com/youtube/v3/
+Default: https://www.googleapis.com
 
 =head2 ua
 
@@ -147,14 +147,10 @@ L<https://developers.google.com/youtube/v3/docs/search/list>
 
 L<Moo>
 
-L<Mojo::JSON>
-
 L<Mojo::UserAgent>
 
 L<Mojo::URL>
 
-L<Try::Tiny>
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
